@@ -15,26 +15,32 @@ c       ---     (1992). J. Geophys. Res. 97, pp. 19845-19871.
 c     Ogata, Y., Matsu'ura S.R., Katsura, K. (1993). submitted to 
 c                Geophys. Res. Letters.
 c-----------------------------------------------------------------------
-      implicit real * 8 (a-h,o-z)
+cx      implicit real * 8 (a-h,o-z)
 cc      parameter(ldata=17777, npara=5)
 cc      common/xyod/xx(ldata),xmg(ldata),xmag0
 cc      common/param/xini(npara),n
-      dimension xx(nd),xmg(nd)
-      dimension xini(n)
+cx      dimension xx(nd),xmg(nd)
+cx      dimension xini(n)
+      integer :: nd, n, nfunct0, iappr0, nlmax, id(nlmax), nl
+      real(8) :: xx(nd), xmg(nd), xmag0, amx1, xini(n), zts, zte,
+     1           tstart0, f, x(n), g(n), aic2, ee(nlmax), xx1(n,nlmax)
+      real(8) :: t, tstart
       common /range/tstart,ntstar
       common /kkxy/kkx,kky,kkt
       common t,nn,mm,iappr,nfunct
 c
-      dimension  x(n), g(n)
-      dimension id(nlmax),ee(nlmax),xx1(n,nlmax)
+cx      dimension  x(n), g(n)
+cx      dimension id(nlmax),ee(nlmax),xx1(n,nlmax)
 c
       nl = 0
-      do 30 i = 1,nlmax
-   30 id(i) = 0
+cx      do 30 i = 1,nlmax
+cx   30 id(i) = 0
+      id(1:nlmax) = 0
 c
 cc      call input
-      call input(xx,xmg,nd,xmag0,amx1,xini,n,zts,zte,tstart0,
-     &           nfunct0,iappr0)
+cx      call input(xx,xmg,nd,xmag0,amx1,xini,n,zts,zte,tstart0,
+cx     &           nfunct0,iappr0)
+      call input(xx,xmg,nd,amx1,zts,zte,tstart0,nfunct0,iappr0)
 c
 cc      do 10 i=2,nn
 cc      if(xx(i).ge.xx(i-1)) go to 10
@@ -45,33 +51,37 @@ cc      write(6,8) nfunct
 cc    8 format(1h ,' funct = ',i5)
 cc      write(6,9) t,nn,mm
 cc      write(6,5) xmag0
-    5 format(1h ,'reference magnitudes; xmag0',5x,f10.4)
-    3 format(1h ,10f12.4/(1h ,10f12.4))
-    9 format(1h ,'t,nn,mm',5x,f10.4,2i6)
-    2 format(f10.2,2i10)
-    1 format(8f10.2)
+cx    5 format(1h ,'reference magnitudes; xmag0',5x,f10.4)
+cx    3 format(1h ,10f12.4/(1h ,10f12.4))
+cx    9 format(1h ,'t,nn,mm',5x,f10.4,2i6)
+cx    2 format(f10.2,2i10)
+cx    1 format(8f10.2)
 c
 cc      call finout
       call finout(xx,xmg,xmag0,nn,xini,n,f,x,g,aic2,id,ee,xx1,nl,nlmax)
 c
-   20 continue
+cx   20 continue
       return
       end
 c***********************************************************************
 cc      subroutine input
-      subroutine input(xx,xmg,nd,xmag0,amx1,xini,n,zts,zte,tstart0,
+cx      subroutine input(xx,xmg,nd,xmag0,amx1,xini,n,zts,zte,tstart0,
+      subroutine input(xx,xmg,nd,amx1,zts,zte,tstart0,
      &                 nfunct0,iappr0)
 c
 c       Reading parameters
 c
-      implicit real * 8 (a-h,o-z)
+cc      implicit real * 8 (a-h,o-z)
 cc      parameter(ldata=17777, npara=5)
 cc      common/param/xini(npara),n
-      dimension  xini(n)
+cx      dimension  xini(n)
 cc      dimension z(ldata),amg(ldata)
 cc      character*80 hypodata
 cc      common /xyod/xx(ldata),xmg(ldata),xmag0
-      dimension  xx(nd),xmg(nd)
+cx      dimension  xx(nd),xmg(nd)
+      integer :: nd, nfunct0, iappr0
+      real(8) :: xx(nd), xmg(nd), amx1, zts, zte, tstart0
+      real(8) :: t, tstart, smg, amct, bvl
       common /kkxy/kkx,kky,kkt
 cc      common /fukasa/dep(ldata)
       common t,nn,mm,iappr,nfunct
@@ -80,7 +90,7 @@ cc      open(unit=1,file='etas.open')
 c     open(unit=1,file='./etaspc.open')
 c     open(unit=1,file='siminit.dat')
 *     read(1,112) hypodata
-  112 format(a)
+cx  112 format(a)
 cc      amx2=10.0
 cc      read(1,*) nfunct,iappr
 cc      read(1,*) zts,zte,tstart
@@ -96,12 +106,12 @@ cc      read(1,*) (xini(i),i=1,n)
 cc      close(unit=1)
 cc      write(6,*) '      minmag, dep1, ts, tend,tstart'
 cc      write(6,5) amx1,zts,zte,tstart
-    1 format(1h ,20a4)
-    4 format(8f10.3)
-    5 format(1h ,8f10.3)
-    9 format(3i10)
-    2 format(f10.0,i10)
-    3 format(20a4)
+cx    1 format(1h ,20a4)
+cx    4 format(8f10.3)
+cx    5 format(1h ,8f10.3)
+cx    9 format(3i10)
+cx    2 format(f10.0,i10)
+cx    3 format(20a4)
 c
 cc      call zisin(t,nd,z,amg,dep,hypodata)
 c
@@ -117,7 +127,7 @@ c     if(dep(i).lt.depx1.or.dep(i).gt.depx2) go to 10
 cc      if(z(i).lt.zts.or.z(i).gt.zte) go to 10
       nn=nn+1
 cc      write(6,1002) nn,i,amg(i),z(i),dep(i)
- 1002 format(2i7,4f12.5,f5.0)
+cx 1002 format(2i7,4f12.5,f5.0)
 cc      if(z(i).lt.tstart) ntstar=nn
 cc      xx(nn)=z(i)-zts
       if(xx(i).lt.tstart) ntstar=nn
@@ -128,7 +138,7 @@ cc      dep(nn)=dep(i)
       if(xmg(nn).ge.amct) smg=smg+(xmg(nn)-amct+.05)
       if(xmg(nn).ge.amct) nnn=nnn+1
    10 continue
-  111 format(3(i5,f12.5,f4.1))
+cx  111 format(3(i5,f12.5,f4.1))
       mm=nd
       bvl=nnn/log(10.)/smg
 cc      write(6,*) 'read #data; selected #data; #tstart; b-value; M_0'
@@ -141,68 +151,83 @@ c***********************************************************************
 cc      subroutine finout
       subroutine finout(xx,xmg,xmag0,ldata,xini,n,ff,x,g,aic20,
      &   id,ee,x1,nl,nlmax)
-      implicit real * 8 (a-h,o-z)
+cx      implicit real * 8 (a-h,o-z)
 cc      parameter(ldata=17777,npara=5)
 cc      external func4,func9
 cc      common/xyod/xx(ldata),xmg(ldata),xmag0
       external func4,func91
-      dimension xx(ldata),xmg(ldata)
+cx      dimension xx(ldata),xmg(ldata)
+      integer :: ldata, n, nlmax, id(nlmax), nl
+      real(8) :: xx(ldata), xmg(ldata), xmag0, xini(n), ff, x(n),
+     1           g(n), aic20, ee(nlmax), x1(n,nlmax)
+      real(8) :: t, f, aic2
       common t,nn,mm,iappr,nfunct
 cc      common/param/xini(npara),n
-      dimension xini(n)
+cx      dimension xini(n)
       common /ddd/ f,aic2
       common /kkxy/kkx,kky,kkt
 cc      dimension x(npara)
-      dimension x(n)
+cx      dimension x(n)
 c
-      dimension  g(n), id(nlmax), ee(nlmax), x1(n,nlmax)
+cx      dimension  g(n), id(nlmax), ee(nlmax), x1(n,nlmax)
 c
       do 10 i=1,nn
-   10 xmg(i)=xmg(i)-xmag0
+cx   10 xmg(i)=xmg(i)-xmag0
+      xmg(i)=xmg(i)-xmag0
+   10 continue
 c
       do 60 i=1,n
-   60 x(i)=xini(i)
+cx   60 x(i)=xini(i)
+      x(i)=xini(i)
+   60 continue
 cc      write(6,1020)   n
 cc      write(6,1030)  (x(i),i=1,n)
 c
       do 70 i=1,n
-   70 x(i)=sqrt(x(i))
+cx   70 x(i)=sqrt(x(i))
+      x(i)=sqrt(x(i))
+   70 continue
 c
       do 30 ii=1,1 
 c
 cc      if(nfunct.eq.4) call davidn(x,n,4,func4)
 cc      if(nfunct.eq.9) call davidn(x,n,9,func9)
       if(nfunct.eq.4)
-     &       call davidn9(xx,xmg,ldata,x,n,4,func4,g,id,ee,x1,nl,nlmax)
+cx     &       call davidn9(xx,xmg,ldata,x,n,4,func4,g,id,ee,x1,nl,nlmax)
+     &       call davidn9(xx,xmg,ldata,x,n,func4,g,id,ee,x1,nl,nlmax)
       if(nfunct.eq.9)
-     &       call davidn9(xx,xmg,ldata,x,n,9,func91,g,id,ee,x1,nl,nlmax)
+cx     &       call davidn9(xx,xmg,ldata,x,n,9,func91,g,id,ee,x1,nl,nlmax)
+     &       call davidn9(xx,xmg,ldata,x,n,func91,g,id,ee,x1,nl,nlmax)
 c
    30 continue
 c
       do 80 i=1,n
-   80 x(i)=x(i)**2
+cx   80 x(i)=x(i)**2
+      x(i)=x(i)**2
+   80 continue
 c
 cc      write(6,1040) f,(x(i),i=1,n)
       ff=f
       aic2=f+n
- 1005 format(e20.10,3i10)
+cx 1005 format(e20.10,3i10)
 cc      write(6,1001) aic2
       aic20=aic2
- 1001 format(1h ,'aic/2 =',e20.10)
-   20 continue
+cx 1001 format(1h ,'aic/2 =',e20.10)
+cx   20 continue
       return
- 1000 format(3i10,2f15.6)
- 1010 format(8f10.4)
- 1020 format(1h ,'n=',i3)
- 1030 format(1h ,'x=',6e12.5)
- 1040 format(1h , 'neg max lklhd=',1 e16.7
-     3      /' max lklhd est.=',9e12.5/('                 ',9e12.5))
- 1050 format(4d20.13)
- 1060 format(e25.15)
+cx 1000 format(3i10,2f15.6)
+cx 1010 format(8f10.4)
+cx 1020 format(1h ,'n=',i3)
+cx 1030 format(1h ,'x=',6e12.5)
+cx 1040 format(1h , 'neg max lklhd=',1 e16.7
+cx     3      /' max lklhd est.=',9e12.5/('                 ',9e12.5))
+cx 1050 format(4d20.13)
+cx 1060 format(e25.15)
       end
 c***********************************************************************
 cc      subroutine  davidn( x,n,ihes,funct )
-      subroutine  davidn9( xx,xmg,nn,x,n,ihes,funct,
+cx      subroutine  davidn9( xx,xmg,nn,x,n,ihes,funct,
+      subroutine  davidn9( xx,xmg,nn,x,n,funct,
      &                          g,id,ee,xx1,nl,nlmax)
 c
 c          minimization by davidon-fletcher-powell procedure
@@ -218,21 +243,25 @@ c
 c          output:
 c             x:       vector of minimizing solution
 c
-      implicit  real * 8  ( a-h , o-z )
+cx      implicit  real * 8  ( a-h , o-z )
       parameter(npara=5)
       external funct
 cc      dimension  x(npara) , dx(npara) , g(npara) , g0(npara) , y(npara)
 cc      dimension  h(npara,npara) , wrk(npara) , s(npara)
-      dimension  x(n) , dx(n) , g(n) , g0(n) , y(n)
-      dimension  h(n,n) , wrk(n) , s(n)
-c
-      dimension  xx(nn) , xmg(nn)
-      dimension  id(nlmax), ee(nlmax), xx1(n,nlmax)
-c
+cx      dimension  x(n) , dx(n) , g(n) , g0(n) , y(n)
+cx      dimension  h(n,n) , wrk(n) , s(n)
+cx      dimension  xx(nn) , xmg(nn)
+cx      dimension  id(nlmax), ee(nlmax), xx1(n,nlmax)
+      integer :: nn, n, id(nlmax), nl, nlmax
+      real(8) :: xx(nn), xmg(nn), x(n), g(n), ee(nlmax), xx1(n,nlmax)
+      real(8) :: f, aic2, tau1, tau2, eps1, eps2
       common /ccc/ isw,ipr
       common /ddd/ f,aic2
       data  tau1 , tau2  /  1.0d-5 , 1.0d-5  /
       data  eps1 , eps2  / 1.0d-5 , 1.0d-5  /
+      real(8) :: dx(n), g0(n), y(n), h(n,n), wrk(n), s(n), ramda,
+     1           const1, xm, sum, s1, s2, stem, ss, ds2, gtem, ed,
+     2           xmb
       ramda = 0.5d0
       const1 = 1.0d-70
 c
@@ -240,15 +269,20 @@ c          initial estimate of inverse of hessian
 c
 cgk
       iccc=0
-22221 continue
+cx22221 continue
       iccc=iccc+1
 cgk
+      h(1:n,1:n) = 0.0d00
+      s(1:n) = 0.0d00
+      dx(1:n) = 0.0d00
       do  20   i=1,n
-      do  10   j=1,n
-   10 h(i,j) = 0.0d00
-      s(i) = 0.0d00
-      dx(i) = 0.0d00
-   20 h(i,i) = 1.0d00
+cx      do  10   j=1,n
+cx   10 h(i,j) = 0.0d00
+cx      s(i) = 0.0d00
+cx      dx(i) = 0.0d00
+cx   20 h(i,i) = 1.0d00
+      h(i,i) = 1.0d00
+   20 continue
       isw = 0
 c
 cc      call  funct( n,x,xm,g,ig )
@@ -269,17 +303,25 @@ c      iteration
       if( ic .eq. 1 .and. icc .eq. 1 )     go to 120
 c
       do  40   i=1,n
-   40 y(i) = g(i) - g0(i)
+cx   40 y(i) = g(i) - g0(i)
+      y(i) = g(i) - g0(i)
+   40 continue
       do  60   i=1,n
       sum = 0.0d00
       do  50   j=1,n
-   50 sum = sum + y(j) * h(i,j)
-   60 wrk(i) = sum
+cx   50 sum = sum + y(j) * h(i,j)
+      sum = sum + y(j) * h(i,j)
+   50 continue
+cx   60 wrk(i) = sum
+      wrk(i) = sum
+   60 continue
       s1 = 0.0d00
       s2 = 0.0d00
       do  70   i=1,n
       s1 = s1 + wrk(i) * y(i)
-   70 s2 = s2 + dx(i) * y(i)
+cx   70 s2 = s2 + dx(i) * y(i)
+      s2 = s2 + dx(i) * y(i)
+   70 continue
       if( s1.le.const1 .or. s2.le.const1 )  go to 900
       if( s1 .le. s2 )     go to 100
 c
@@ -287,20 +329,28 @@ c          update the inverse of hessian matrix
 c
 c               ---  davidon-fletcher-powell type correction  ---
 c
-      do  90   i=1,n
+cx      do  90   i=1,n
+      do  91   i=1,n
       do  90   j=i,n
       h(i,j) = h(i,j) + dx(i)*dx(j)/s2 - wrk(i)*wrk(j)/s1
-   90 h(j,i) = h(i,j)
+cx   90 h(j,i) = h(i,j)
+      h(j,i) = h(i,j)
+   90 continue
+   91 continue
       go to  120
 c
 c               ---  fletcher type correction  ---
 c
   100 continue
       stem = s1 / s2 + 1.0d00
-      do  110   i=1,n
+cx      do  110   i=1,n
+      do  111   i=1,n
       do  110   j=i,n
       h(i,j) = h(i,j)- (dx(i)*wrk(j)+wrk(i)*dx(j)-dx(i)*dx(j)*stem)/s2
-  110 h(j,i) = h(i,j)
+cx  110 h(j,i) = h(i,j)
+      h(j,i) = h(i,j)
+  110 continue
+  111 continue
 c
 c
 c
@@ -309,26 +359,35 @@ c
       do  150   i=1,n
       sum = 0.0d00
       do  140   j=1,n
-  140 sum = sum + h(i,j)*g(j)
+cx  140 sum = sum + h(i,j)*g(j)
+      sum = sum + h(i,j)*g(j)
+  140 continue
       ss = ss + sum * sum
-  150 s(i) = -sum
+cx  150 s(i) = -sum
+      s(i) = -sum
+  150 continue
 c
 c
       s1 = 0.0d00
       s2 = 0.0d00
       do  170   i=1,n
       s1 = s1 + s(i)*g(i)
-  170 s2 = s2 + g(i)*g(i)
+cx  170 s2 = s2 + g(i)*g(i)
+      s2 = s2 + g(i)*g(i)
+  170 continue
       ds2 = dsqrt(s2)
       gtem = dabs(s1) / ds2
 c     write(6,610)gtem,ds2
       if( gtem .le. tau1  .and.  ds2 .le. tau2 )     go to  900
       if( s1 .lt. 0.0d00 )     go to  200
+      h(1:n,1:n) = 0.0d00
       do  190   i=1,n
-      do  180   j=1,n
-  180 h(i,j) = 0.0d00
+cx      do  180   j=1,n
+cx  180 h(i,j) = 0.0d00
       h(i,i) = 1.0d00
-  190 s(i) = -s(i)
+cx  190 s(i) = -s(i)
+      s(i) = -s(i)
+  190 continue
   200 continue
 c
       ed = xm
@@ -355,7 +414,9 @@ c
       dx(i) = s(i) * ramda
       s1 = s1 + dx(i) * dx(i)
       g0(i) = g(i)
-  210 x(i) = x(i) + dx(i)
+cx  210 x(i) = x(i) + dx(i)
+      x(i) = x(i) + dx(i)
+  210 continue
       xmb = xm
       isw = 0
 c
@@ -364,7 +425,9 @@ cc      call  funct( n,x,xm,g,ig )
 c
       s2 = 0.d0
       do  220     i=1,n
-  220 s2 = s2 + g(i)*g(i)
+cx  220 s2 = s2 + g(i)*g(i)
+      s2 = s2 + g(i)*g(i)
+  220 continue
       if( dsqrt(s2) .gt. tau2 )   go to  11111
       if( xmb/xm-1.d0 .lt. eps1  .and.  dsqrt(s1) .lt. eps2 )  go to 900
 11111 continue
@@ -380,11 +443,11 @@ cc      write( 6,610 )     (g(i)**2,i=1,n)
             id(nl) = 600
          end if
       return
-  330 format( 1h ,'lambda =',d15.7,5x,'-LL =',d23.15,2x,d9.2,2x,d9.2)
-  340 format( 1h ,4x,'initial (-1)*Log-Likelihood =',d23.15)
-  600 format( 1h ,'-----  x  -----' )
-  601 format( 1h ,'***  gradient  ***' )
-  610 format( 1h ,10d13.5 )
+cx  330 format( 1h ,'lambda =',d15.7,5x,'-LL =',d23.15,2x,d9.2,2x,d9.2)
+cx  340 format( 1h ,4x,'initial (-1)*Log-Likelihood =',d23.15)
+cx  600 format( 1h ,'-----  x  -----' )
+cx  601 format( 1h ,'***  gradient  ***' )
+cx  610 format( 1h ,10d13.5 )
       end
 c***********************************************************************
 cc      subroutine  linear( x,h,ram,ee,k,ig,funct )
@@ -408,17 +471,23 @@ c        ram:     optimal step width
 c        e2:      minimum function value
 c        ig:      error code
 c
-      implicit  real  *8 ( a-h,o-z )
+cx      implicit  real  *8 ( a-h,o-z )
 cc      parameter(npara=5)
       external funct
-      integer  return,sub
+cx      integer  return,sub
 cc      dimension  x(npara) , h(npara) , x1(npara)
 cc      dimension  g(npara)
-      dimension  x(k) , h(k) , x1(k)
-      dimension  g(k)
+      integer :: nn, k, ig, id(nlmax), nl, nlmax
+      real(8) :: xx(nn), xmg(nn), x(k), h(k), ram, ee, eee(nlmax),
+     1           xx1(k,nlmax)
+cx      dimension  x(k) , h(k) , x1(k)
+cx      dimension  g(k)
       common /ccc/ isw,ipr
-      dimension  xx(nn) , xmg(nn)
-      dimension  id(nlmax), eee(nlmax), xx1(k,nlmax)
+cx      dimension  xx(nn) , xmg(nn)
+cx      dimension  id(nlmax), eee(nlmax), xx1(k,nlmax)
+      integer :: return, sub
+      real(8) :: x1(k), g(k), const2, hnorm, ram1, ram2, ram3,
+     1           e1, e2, e3, a1, a2, a3, b1, b2
 c
       isw = 1
       ipr=7
@@ -426,7 +495,9 @@ c
       const2 = 1.0d-60
       hnorm = 0.d0
       do 10  i=1,k
-   10 hnorm = hnorm + h(i)**2
+cx   10 hnorm = hnorm + h(i)**2
+      hnorm = hnorm + h(i)**2
+   10 continue
       hnorm = dsqrt( hnorm )
 c
       ram2 = ram
@@ -434,7 +505,9 @@ c
       ram1 = 0.d0
 c
       do 20  i=1,k
-   20 x1(i) = x(i) + ram2*h(i)
+cx   20 x1(i) = x(i) + ram2*h(i)
+      x1(i) = x(i) + ram2*h(i)
+   20 continue
 cc      call  funct( k,x1,e2,g,ig )
       call  funct( xx,xmg,nn,k,x1,e2,g,ig )
 c     if(ipr.ge.7)  write(6,2)  ram2,e2
@@ -444,16 +517,20 @@ cc      if(ipr.ge.7)  write(6,8)  e2,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = e2
          do 21 i=1,k
-   21    xx1(i,nl) = x1(i)
+cx   21    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+   21    continue
       end if
 
-    8 format(' -ll=',d13.5,1x,5d12.5)
+cx    8 format(' -ll=',d13.5,1x,5d12.5)
 c
       if( ig .eq. 1 )  go to  50
       if( e2 .gt. e1 )  go to 50
    30 ram3 = ram2*2.d0
       do 40  i=1,k
-   40 x1(i) = x(i) + ram3*h(i)
+cx   40 x1(i) = x(i) + ram3*h(i)
+      x1(i) = x(i) + ram3*h(i)
+   40 continue
 cc      call  funct( k,x1,e3,g,ig )
       call  funct( xx,xmg,nn,k,x1,e3,g,ig )
       if( ig.eq.1 )  go to  500
@@ -464,7 +541,9 @@ cc      if(ipr.ge.7)  write(6,8)  e3,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = e3
          do 41 i=1,k
-   41    xx1(i,nl) = x1(i)
+cx   41    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+   41    continue
       end if
       if( e3 .gt. e2 )  go to 70
       ram1 = ram2
@@ -478,7 +557,9 @@ c
       ram2 = ram3*0.1d0
       if( ram2*hnorm .lt. const2 )  go to  400
       do 60  i=1,k
-   60 x1(i) = x(i) + ram2*h(i)
+cx   60 x1(i) = x(i) + ram2*h(i)
+      x1(i) = x(i) + ram2*h(i)
+   60 continue
 cc      call  funct( k,x1,e2,g,ig )
       call  funct( xx,xmg,nn,k,x1,e2,g,ig )
 c     if(ipr.ge.7)  write(6,4)  ram2,e2
@@ -488,7 +569,9 @@ cc      if(ipr.ge.7)  write(6,8)  e2,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = e2
          do 61 i=1,k
-   61    xx1(i,nl) = x1(i)
+cx   61    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+   61    continue
       end if
 
       if( e2.gt.e1 )  go to 50
@@ -498,7 +581,9 @@ cc   70 assign 80 to return
       go to 200
 c
    80 do 90  i=1,k
-   90 x1(i) = x(i) + ram*h(i)
+cx   90 x1(i) = x(i) + ram*h(i)
+      x1(i) = x(i) + ram*h(i)
+   90 continue
 cc      call  funct( k,x1,ee,g,ig )
       call  funct( xx,xmg,nn,k,x1,ee,g,ig )
 c     if(ipr.ge.7)  write(6,5)  ram,ee
@@ -508,7 +593,9 @@ cc      if(ipr.ge.7)  write(6,8)  ee,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = ee
          do 91 i=1,k
-   91    xx1(i,nl) = x1(i)
+cx   91    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+   91    continue
       end if
 
 c
@@ -550,7 +637,9 @@ cc      go to  sub,( 200,300 )
       if( sub.eq.300 ) go to 300
 c
   130 do 140  i=1,k
-  140 x1(i) = x(i) + ram*h(i)
+cx  140 x1(i) = x(i) + ram*h(i)
+      x1(i) = x(i) + ram*h(i)
+  140 continue
 cc      call  funct( k,x1,ee,g,ig )
       call  funct( xx,xmg,nn,k,x1,ee,g,ig )
 c     if( ipr.ge.7 )  write(6,6)  ram,ee
@@ -560,7 +649,9 @@ cc      if(ipr.ge.7)  write(6,8)  ee,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = ee
          do 141 i=1,k
-  141    xx1(i,nl) = x1(i)
+cx  141    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+  141    continue
       end if
 cc      assign 200 to sub
       sub = 200
@@ -607,7 +698,9 @@ c ------------------------------------------------------------
 c
   500 ram = (ram2+ram3)*0.5d0
   510 do 520  i=1,k
-  520 x1(i) = x(i) + ram*h(i)
+cx  520 x1(i) = x(i) + ram*h(i)
+      x1(i) = x(i) + ram*h(i)
+  520 continue
 cc      call  funct( k,x1,e3,g,ig )
       call  funct( xx,xmg,nn,k,x1,e3,g,ig )
 c     if( ipr.ge.7 )  write(6,7)  ram,e3
@@ -617,7 +710,9 @@ cc      if(ipr.ge.7)  write(6,8)  e3,(x1(i)**2,i=1,k)
          id(nl) = 8
          eee(nl) = e3
          do 521 i=1,k
-  521    xx1(i,nl) = x1(i)
+cx  521    xx1(i,nl) = x1(i)
+         xx1(i,nl) = x1(i)
+  521    continue
       end if
 
       if( ig.eq.1 )  go to 540
@@ -635,13 +730,13 @@ c
       go to 510
 c
 c ------------------------------------------------------------
-    1 format( 1h ,'lambda =',d18.10, 10x,'e1 =',d25.17 )
-    2 format( 1h ,'lambda =',d18.10, 10x,'e2 =',d25.17 )
-    3 format( 1h ,'lambda =',d18.10, 10x,'e3 =',d25.17 )
-    4 format( 1h ,'lambda =',d18.10, 10x,'e4 =',d25.17 )
-    5 format( 1h ,'lambda =',d18.10, 10x,'e5 =',d25.17 )
-    6 format( 1h ,'lambda =',d18.10, 10x,'e6 =',d25.17 )
-    7 format( 1h ,'lambda =',d18.10, 10x,'e7 =',d25.17 )
+cx    1 format( 1h ,'lambda =',d18.10, 10x,'e1 =',d25.17 )
+cx    2 format( 1h ,'lambda =',d18.10, 10x,'e2 =',d25.17 )
+cx    3 format( 1h ,'lambda =',d18.10, 10x,'e3 =',d25.17 )
+cx    4 format( 1h ,'lambda =',d18.10, 10x,'e4 =',d25.17 )
+cx    5 format( 1h ,'lambda =',d18.10, 10x,'e5 =',d25.17 )
+cx    6 format( 1h ,'lambda =',d18.10, 10x,'e6 =',d25.17 )
+cx    7 format( 1h ,'lambda =',d18.10, 10x,'e7 =',d25.17 )
       end
 c***********************************************************************
 cc      subroutine func4(n,b,f,h,ifg)
@@ -653,16 +748,23 @@ c     the optimization w.r.t. a5 is not yet succeeded
 c     at the date of 26th oct. 1981.
 c     -----this is succeeded at 23 dec.1983-----
 c----------------------------------------------------------------------
-      implicit real * 8 (a-h,o-z)
+cx      implicit real * 8 (a-h,o-z)
 cc      parameter(ldata=17777, npara=5)
 cc      common/xyod/xx(ldata),xmg(ldata),xmag0
-      dimension xx(ldata),xmg(ldata)
+cx      dimension xx(ldata),xmg(ldata)
+      integer :: ldata, n, ifg
+      real(8) :: xx(ldata), xmg(ldata), b(n), f, h(n)
+      real(8) :: t, fff, aic2, tstart
       common t,nn,mm,iappr
       common /ddd/fff,aic2
       common /range/tstart,ntstar
       common /kkxy/kkx,kky,kkt
 cc      dimension b(npara),h(npara),ggt(npara),gt(npara),at(npara)
-      dimension b(n),h(n),ggt(n),gt(n),at(n)
+cx      dimension b(n),h(n),ggt(n),gt(n),at(n)
+      real(8) :: ggt(n), gt(n), at(n), a1, a2, a3, a4, a5, ff,
+     1           d1ff, d2ff, d3ff, d4ff, d5ff, rmdti1, ramdai, rmdi,
+     2           rmd1i, rmdmi, rmdli, ft, d3ft, d4ft, d5ft, fs, d1fs,
+     3           d2fs, d3fs, d4fs, d5fs, stsum, g1, g2, g3, g4, g5
       ifg=0
       a1=b(1)**2
       a2=b(2)**2
@@ -680,15 +782,20 @@ c
       d4ff=0.0
       d5ff=0.0
       do 110 k=1,kkt
-  110 at(k)=b(k+5)
-      do 120 k=1,kkt
-  120 ggt(k)=0.0
+cx  110 at(k)=b(k+5)
+      at(k)=b(k+5)
+  110 continue
+cx      do 120 k=1,kkt
+cx  120 ggt(k)=0.0
+      ggt(1:kkt)=0.0
       rmdti1=0.0
 c
       if(xx(1).lt.tstart) go to 130
 c
       do 140 k=1,kkt
-  140 rmdti1=rmdti1+at(k)*(xx(1)/t)**k
+cx  140 rmdti1=rmdti1+at(k)*(xx(1)/t)**k
+      rmdti1=rmdti1+at(k)*(xx(1)/t)**k
+  140 continue
       ramdai=a1+rmdti1
       if(ramdai.le.0.0) go to 50
       ff=log(ramdai)
@@ -719,7 +826,9 @@ c
       rmdti1=0.0
       if(kkt.eq.0) go to 160
       do 170 k=1,kkt
-  170 rmdti1=rmdti1+at(k)*(xx(i)/t)**k
+cx  170 rmdti1=rmdti1+at(k)*(xx(i)/t)**k
+      rmdti1=rmdti1+at(k)*(xx(i)/t)**k
+  170 continue
   160 continue
 c
       ramdai=a1+a2*rmdi+rmdti1
@@ -823,13 +932,15 @@ c
       h(4)=-g4*2.0d0*b(4)
       h(5)=-g5*2.0d0*b(5)
       do 100 k=1,kkt
-  100 h(k+5)=-gt(k)
+cx  100 h(k+5)=-gt(k)
+      h(k+5)=-gt(k)
+  100 continue
       if(a5.eq.1.d0) h(5)=0.0
       fff=f
 c     write(6,1030) fff,a1,a2,a3,a4,a5
- 1030 format(1h ,'f=',e12.5,'; x=',6e12.5)
-    3 format(1h ,110x,d18.10)
-    1 format(1h ,7d18.10)
+cx 1030 format(1h ,'f=',e12.5,'; x=',6e12.5)
+cx    3 format(1h ,110x,d18.10)
+cx    1 format(1h ,7d18.10)
       return
    50 continue
       ifg=1
@@ -847,18 +958,31 @@ c     when is=16, the gradient were not converge because approximation
 c     for a3 did not fit well. this subrourine has overcomed this
 c     by making use of the direct diffrerential of lamdai: see pi#(.).
 c-----------------------------------------------------------------------
-      implicit real * 8 (a-h,o-z)
+cx      implicit real * 8 (a-h,o-z)
 cc      parameter(ldata=17777, npara=5)
 cc      common/xyod/xx(ldata),xmg(ldata),xmag0
-      dimension xx(ldata),xmg(ldata)
+      integer :: ldata, n, ifg
+      real(8) :: xx(ldata), xmg(ldata), b(n), f, h(n)
+      real(8) :: t, fff, aic2, tstart
+cx      dimension xx(ldata),xmg(ldata)
       common t,nn,mm,iappr
       common /ddd/fff,aic2
       common /range/tstart,ntstar
 cc      dimension b(npara),h(npara)
-      dimension b(n),h(n)
-      dimension xi1(144),xi2(144),wx1(144),wx2(144)
-      dimension fi1(144),fi2(144),alf1(144),alf2(144),ci1(144),ci2(144)
-      dimension rmd(ldata),rmdc(ldata),rmdm(ldata),rmdl(ldata)
+cx      dimension b(n),h(n)
+cx      dimension xi1(144),xi2(144),wx1(144),wx2(144)
+cx      dimension fi1(144),fi2(144),alf1(144),alf2(144),ci1(144),ci2(144)
+cx      dimension rmd(ldata),rmdc(ldata),rmdm(ldata),rmdl(ldata)
+      integer :: ixhiab
+      real(8) :: xi1(144), xi2(144), wx1(144), wx2(144), fi1(144),
+     1           fi2(144), alf1(144), alf2(144), ci1(144), ci2(144),
+     2           rmd(ldata), rmdc(ldata), rmdm(ldata), rmdl(ldata),
+     3           delta0, xi0, wx0, pi2, delta, a1, a2, a3, a4, a5,
+     4           ff, d1ff, d2ff, d3ff, d4ff, d5ff, rmdi, rmdci, rmdmi,
+     5           rmdli, fi0, ci0, alf0, cpg, cpg3, cpg5, qi0,
+     6           gi0, hi0, blf0, qi1, qi2, gi1, hi1, gi2, hi2, gam,
+     7           blf1, blf2, ramdai, d3ft, d4ft, d5ft, ft, effmag, fs,
+     8           d1fs, d2fs, d3fs, d4fs, d5fs, g1, g2, g3, g4, g5
       data ixhiab /0/
       save ixhiab,delta0,xi0,xi1,xi2,wx0,wx1,wx2
 c
@@ -1067,9 +1191,9 @@ c
       if(a5.eq.1.d0) h(5)=0.0
       fff=f
 c     write(6,1030) fff,a1,a2,a3,a4,a5
- 1030 format(1h ,'f=',e12.5,'; x=',6e12.5)
-    3 format(1h ,110x,d18.10)
-    1 format(1h ,7d13.6)
+cx 1030 format(1h ,'f=',e12.5,'; x=',6e12.5)
+cx    3 format(1h ,110x,d18.10)
+cx    1 format(1h ,7d13.6)
       return
    50 continue
       ifg=1
@@ -1078,8 +1202,10 @@ c     write(6,1030) fff,a1,a2,a3,a4,a5
       end
 c***********************************************************************
       subroutine hiab(h,a0,a1,a2,b0,b1,b2)
-      implicit real*8(a-h,o-z)
-      dimension a1(144),a2(144),b1(144),b2(144)
+cx      implicit real*8(a-h,o-z)
+cx      dimension a1(144),a2(144),b1(144),b2(144)
+      real(8) :: h, a0, a1(144), a2(144), b0, b1(144), b2(144)
+      real(8) :: pi2, eh, ehi, eni, en, s1
       pi2=1.570796326794397d0
       h=1.d0/32
       eh=exp(h)
@@ -1102,15 +1228,21 @@ c***********************************************************************
       end
 c***********************************************************************
 c     real*8 function gam(id,q)
-      real*8 function dbgam(id,q)
+cx      real*8 function dbgam(id,q)
+      double precision function dbgam(id,q)
 c hitac    real function dbgam*8(id,q)
-      implicit real*8(a-h, o-z)
-      dimension a(10)
+cx      implicit real*8(a-h, o-z)
+cx      dimension a(10)
+      integer :: id
+      real(8) :: q
+      real(8) :: a(10)
       data a/ 0.99999 99998 71452d0, 0.42278 43615 29813d0,
      1        0.41183 94326 49605d0, 0.08158 87915 49927d0,
      2        0.07416 87114 09713d0, 0.00004 89152 06125d0,
      3        0.01038 02945 70428d0, -.00162 85524 78086d0,
      4        0.00082 46883 39196d0, -.00000 66427 76723d0 /
+      real(8) :: fact, dfac, d2fac, p, x, gamm, gam1, dgam, d2gam,
+     1           eps, gam
       fact=1
       dfac=0.0
       d2fac=0.0
@@ -1155,12 +1287,16 @@ c
       end
 c***********************************************************************
 c     real*8 function qbgam(id,qq)
-      real*8 function gam(id,qq)
+cx      real*8 function gam(id,qq)
+      double precision function gam(id,qq)
 c hitac     real function gam*8(id,q)
 c     implicit real*16(a-h, o-z)
-      implicit real* 8(a-h, o-z)
-      real*8 qq
-      dimension a(11),b(11)
+cx      implicit real* 8(a-h, o-z)
+cx      real*8 qq
+cx      dimension a(11),b(11)
+      integer :: id
+      real(8) :: qq
+      real(8) :: a(11), b(11)
       data a/ -2 98354.32785 74342 13883 04376 59         d0,
      1        -2 38495.39700 18198 87246 87344 23         d0,
      2        -1 17049.47601 21780 68840 38544 45         d0,
@@ -1183,6 +1319,8 @@ c     implicit real*16(a-h, o-z)
      8               1.                                   d0,
      9               0.0                                  d0,
      t               0.0                                  d0 /
+      real(8) :: fact, dfac, d2fac, p, x, gam1, gam2, dga1,
+     1           dga2, d2ga1, d2ga2, eps
       fact=1
       dfac=0.0
       d2fac=0.0
@@ -1211,7 +1349,9 @@ c
       gam2=b(1)
       do 10 i=2,11
       gam1=gam1+a(i)*x**(i-1)
-   10 gam2=gam2+b(i)*x**(i-1)
+cx   10 gam2=gam2+b(i)*x**(i-1)
+      gam2=gam2+b(i)*x**(i-1)
+   10 continue
       dga1=a(2)
       dga2=b(2)
       do 40 i=3,11
